@@ -26,11 +26,11 @@ from .invite_links import InviteLinks
 from .messages import Messages
 from .password import Password
 from .premium import Premium
-from .pyromod import Pyromod
 from .users import Users
 from .stories import Stories
 from .stickers import Stickers
 from .utilities import Utilities
+from .pyromod import Pyromod
 
 
 class Methods(
@@ -47,7 +47,7 @@ class Methods(
     Decorators,
     Stickers,
     Utilities,
-    Pyromod,
     InviteLinks,
+    Pyromod
 ):
     pass
